@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::ChangeStats::Git;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: add code churn statistics to the changelog
-$Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.4.0';
+$Dist::Zilla::Plugin::ChangeStats::Git::VERSION = '0.5.0';
 
 use strict;
 use warnings;
@@ -20,9 +20,11 @@ with qw/
 /;
 
 with 'Dist::Zilla::Role::Author::YANICK::RequireZillaRole' => {
-    roles => [ qw/ Author::YANICK::Changelog / ],
+    roles => [ '+Dist::Zilla::Role::Author::YANICK::Changelog' ],
 };
 
+sub mvp_multivalue_args { qw/ skip_file skip_match / }
+
 has repo => (
     is => 'ro',
     default => sub { Git::Repository->new( work_tree => '.' ) },
@@ -56,12 +58,54 @@ has group => (
     default => '',
 );
 
+has skip_file => (
+    is => 'ro',
+    isa => 'ArrayRef[Str]',
+    default => sub { [] },
+    traits => ['Array'],
+    handles => {
+        all_skip_files => 'elements',
+        has_skip_files => 'count',
+    }
+);
+
+has skip_match => (
+    is => 'ro',
+    isa => 'ArrayRef[Str]',
+    default => sub { [] },
+    traits => ['Array'],
+    handles => {
+        all_skip_matches => 'elements',
+        has_skip_matches => 'count',
+    }
+);
+
+has text => (
+    is => 'ro',
+    isa => 'Str',
+    default => 'code churn',
+);
+
+
 has stats => (
     is => 'ro',
     lazy => 1,
     default => sub {
         my $self = shift;
 
+	my $comparison_data = $self->_get_comparison_data;
+	if ( defined $comparison_data ) {
+		my $stats = (length $self->text ? $self->text . ': ' : '') . $comparison_data;
+		$stats =~ s/\s+/ /g;
+		return $stats;
+	} else {
+		return;
+	}
+    }
+);
+sub _get_comparison_data {
+	my $self = shift;
+
 	# What are we diffing against? :)
 	my( $prev, $next ) = ( $self->release_branch, $self->develop_branch );
 	if ( $self->auto_previous_tag ) {
@@ -69,20 +113,41 @@ has stats => (
 		return if ! defined $prev;
 	}
 	$self->log_debug( "Comparing '$prev' against '$next' for code stats" );
-        my @output = $self->repo->run( 'diff', '--stat',
-            join '...', $prev, $next
-        );
 
-        # actually, only the last line is interesting
-	if ( defined $output[-1] ) {
-	        my $stats = "code churn: " . $output[-1];
-		$stats =~ s/\s+/ /g;
-	        return $stats;
-	} else {
-		return;
+	my $output;
+	if($self->has_skip_files || $self->has_skip_matches) {
+		my @numstats = $self->repo->run( 'diff', '--numstat',
+		    join '...', $prev, $next
+		);
+		my $data = { files => 0, insertions => 0, deletions => 0 };
+
+		ITEM:
+		for my $item (@numstats) {
+			my($insertions, $deletions, $path) = split /\s+/, $item, 3;
+			next ITEM if grep { $path eq $_ } $self->all_skip_files;
+			next ITEM if grep { $path =~ m{$_}i } $self->all_skip_matches;
+
+			# binary files get '-' for insertions/deletions
+			++$data->{'files'};
+			$data->{'insertions'} += $insertions =~ m{^\d+$} ? $insertions : 0;
+			$data->{'deletions'} += $deletions =~ m{^\d+$} ? $insertions : 0;
+		}
+
+		$output = sprintf '%d file%s changed, %d insertion%s(+), %d deletion%s(-)',
+				  $data->{'files'},
+				  $data->{'files'} == 1 ? '' : 's',
+				  $data->{'insertions'},
+				  $data->{'insertions'} == 1 ? '' : 's',
+				  $data->{'deletions'},
+				  $data->{'deletions'} == 1 ? '' : 's';
 	}
-  } 
-);
+	else {
+		($output) = $self->repo->run( 'diff', '--shortstat',
+		    join '...', $prev, $next
+		);
+	}
+	return $output;
+}
 
 sub _get_previous_tag {
 	my( $self ) = @_;
@@ -118,10 +183,10 @@ sub munge_files {
 sub after_release {
   my $self = shift;
   return unless $self->stats;
-  my $changes = CPAN::Changes->load( 
+  my $changes = CPAN::Changes->load(
       $self->zilla->changelog_name,
       next_token => qr/\{\{\$NEXT\}\}/
-  ); 
+  );
 
   for my $next ( reverse $changes->releases ) {
     next if $next->version =~ /NEXT/;
@@ -153,7 +218,7 @@ Dist::Zilla::Plugin::ChangeStats::Git - add code churn statistics to the changel
 
 =head1 VERSION
 
-version 0.4.0
+version 0.5.0
 
 =head1 SYNOPSIS
 
@@ -161,6 +226,7 @@ version 0.4.0
 
     [ChangeStats::Git]
     group=STATISTICS
+    skip_match=^meta
 
 =head1 DESCRIPTION
 
@@ -188,6 +254,20 @@ previous release's tag. This will be then compared against the develop_branch. D
 
 The branch recording the releases. Defaults to I<releases>.
 
+=head2 text
+
+The text before git output. If it is a non-empty string, C<:E<lt>spaceE<gt>> will be appended. Defaults to I<code churn>.
+
+=head2 skip_file
+
+A complete path (from the distribution root) that should not be included in the statistics. Can be given
+multiple times.
+
+=head2 skip_match
+
+A part of a regex used to match against complete paths. Paths that match are not included in the statistics. Can be
+given multiple times.
+
 =head1 AUTHOR
 
 Yanick Champoux <yanick@cpan.org>
