@@ -1,6 +1,6 @@
 package Dist::Zilla::Role::Author::YANICK::RequireZillaRole;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::Role::Author::YANICK::RequireZillaRole::VERSION = '0.4.0';
+$Dist::Zilla::Role::Author::YANICK::RequireZillaRole::VERSION = '0.5.0';
 use strict;
 use warnings;
 
@@ -26,8 +26,9 @@ role {
         $zilla->meta->make_mutable;
 
         for my $role ( @{ $p->roles } ) {
+
             $role =~ s/^\+// 
-                or $role =~ s/^/Dist::Zilla::Role::/;
+                or $role =~ s/^/Dist::Zilla::Role::/ if $role !~ m/^Dist::Zilla::Role::/;
 
             next if $zilla->does($role);
 
@@ -56,7 +57,7 @@ Dist::Zilla::Role::Author::YANICK::RequireZillaRole
 
 =head1 VERSION
 
-version 0.4.0
+version 0.5.0
 
 =head1 AUTHOR
 
